@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2014 Cinc
+# Copyright (C) 2014-2020 Cinc
 #
 # License: 3-clause BSD
 #
 from collections import defaultdict
+from pkg_resources import resource_filename
 from trac.config import BoolOption
 from trac.core import *
 from trac.resource import ResourceNotFound
@@ -14,11 +15,10 @@ from trac.ticket.api import IMilestoneChangeListener
 from trac.util.translation import _
 from trac.web.api import IRequestFilter
 from trac.web.chrome import add_script, \
-    add_script_data, add_stylesheet
+    add_script_data, add_stylesheet, ITemplateProvider
 
 from simplemultiproject.compat import JTransformer
 from simplemultiproject.milestone import create_projects_table_j
-from simplemultiproject.model import SmpModel
 from simplemultiproject.smp_model import SmpComponent, SmpProject, \
     SmpVersion, SmpMilestone
 
@@ -36,6 +36,8 @@ def _allow_no_project(self):
 class SmpFilterBase(Component):
     """Must be activated when SmpFilterDefaultMilestonePanels or SmpFilterDefaultVersionPanels are used."""
 
+    implements(ITemplateProvider)
+
     # The following are verridden in subclass
     template_name = ""  # name of html file
     add_form_id = ''  # id of form used to add a new item on main admin page
@@ -45,9 +47,17 @@ class SmpFilterBase(Component):
     single_project = False
 
     def __init__(self):
-        self._SmpModel = SmpModel(self.env)
         self.smp_project = SmpProject(self.env)
 
+    # ITemplateProvider methods
+
+    def get_templates_dirs(self):
+        self.log.info(resource_filename(__name__, 'templates'))
+        return [resource_filename(__name__, 'templates')]
+
+    def get_htdocs_dirs(self):
+        return [('simplemultiproject', resource_filename(__name__, 'htdocs'))]
+
     @staticmethod
     def is_valid_request(req, path):
         """Check request for correct path and valid form token"""
@@ -125,7 +135,7 @@ class SmpFilterBase(Component):
         # Insert project selection control
         # xpath: //form[@id="addmilestone"]//div[@class="field"][1]
         xform = JTransformer('form#%s div.field:nth-of-type(1)' % form_id)
-        filter_list.append(xform.after(create_projects_table_j(self, self._SmpModel, req,
+        filter_list.append(xform.after(create_projects_table_j(self, req,
                                                                input_type=input_type)))
         if filter_list:
             add_script_data(req, {'smp_filter': filter_list})
@@ -153,7 +163,7 @@ class SmpFilterBase(Component):
         # Insert project selection control
         # xpath: //form[@id="edit"]//div[@class="field"][1]
         xform = JTransformer('form#edit div.field:nth-of-type(1)')
-        filter_list = [xform.after(create_projects_table_j(self, self._SmpModel, req, input_type=input_type))]
+        filter_list = [xform.after(create_projects_table_j(self, req, input_type=input_type))]
 
         add_script_data(req, {'smp_filter': filter_list})
         add_script(req, 'simplemultiproject/js/jtransform.js')
@@ -359,10 +369,9 @@ class SmpFilterDefaultComponentPanels(Component):
     simplemultiproject.admin_component.* = disabled
     }}}
     """
-    implements(IRequestFilter)
+    implements(IRequestFilter, ITemplateProvider)
 
     def __init__(self):
-        self._SmpModel = SmpModel(self.env)
         self.smp_model = SmpComponent(self.env)
         self.smp_project = SmpProject(self.env)
 
@@ -421,7 +430,7 @@ class SmpFilterDefaultComponentPanels(Component):
                 # The 'Add component' part of the page
                 # xpath: //form[@id="addcomponent"]//div[@class="field"][2]
                 xform = JTransformer('form#addcomponent div.field:nth-of-type(2)')
-                filter_list.append(xform.after(create_projects_table_j(self, self._SmpModel, req)))
+                filter_list.append(xform.after(create_projects_table_j(self,  req)))
 
                 # xpath: //table[@id="complist"]
                 xform = JTransformer('table#complist')
@@ -444,10 +453,19 @@ class SmpFilterDefaultComponentPanels(Component):
                 # xform: //form[@id="modcomp" or @id="edit"]//div[@class="field"][1] where is modcomp used?
                 # xform: //form[@id="edit"]//div[@class="field"][1]
                 xform = JTransformer('form#edit div.field:nth-of-type(1)')
-                filter_list.append(xform.after(create_projects_table_j(self, self._SmpModel, req)))
+                filter_list.append(xform.after(create_projects_table_j(self, req)))
 
             if filter_list:
                 add_script_data(req, {'smp_filter': filter_list})
                 add_script(req, 'simplemultiproject/js/jtransform.js')
 
         return template, data, content_type
+
+    # ITemplateProvider methods
+
+    def get_templates_dirs(self):
+        self.log.info(resource_filename(__name__, 'templates'))
+        return [resource_filename(__name__, 'templates')]
+
+    def get_htdocs_dirs(self):
+        return [('simplemultiproject', resource_filename(__name__, 'htdocs'))]
